@@ -1,9 +1,4 @@
-# Copyright (C) 2016, the Pyzo development team
-#
-# Pyzo is distributed under the terms of the 2-Clause BSD License.
-# The full license can be found in 'license.txt'.
-
-""" Module editor
+"""Module editor
 
 Defines the PyzoEditor class which is used to edit documents.
 This module/class also implements all the relatively low level
@@ -11,8 +6,10 @@ file loading/saving /reloading stuff.
 
 """
 
-import os, sys
-import re, codecs
+import os
+import sys
+import re
+import codecs
 
 from pyzo.qt import QtCore, QtGui, QtWidgets
 
@@ -395,8 +392,12 @@ class PyzoEditor(BaseTextCtrl):
                 "File has been modified outside of the editor:\n" + self._filename
             )
             dlg.setInformativeText("Do you want to reload?")
-            btnReload = dlg.addButton("Reload", QtWidgets.QMessageBox.ButtonRole.AcceptRole)
-            dlg.addButton("Keep this version", QtWidgets.QMessageBox.ButtonRole.RejectRole)
+            btnReload = dlg.addButton(
+                "Reload", QtWidgets.QMessageBox.ButtonRole.AcceptRole
+            )
+            dlg.addButton(
+                "Keep this version", QtWidgets.QMessageBox.ButtonRole.RejectRole
+            )
             dlg.setDefaultButton(btnReload)
 
             # whatever the result, we will reset the modified time
@@ -512,7 +513,8 @@ class PyzoEditor(BaseTextCtrl):
                 ):
                     editCursor.movePosition(editCursor.MoveOperation.StartOfBlock)
                     editCursor.movePosition(
-                        editCursor.MoveOperation.EndOfBlock, editCursor.MoveMode.KeepAnchor
+                        editCursor.MoveOperation.EndOfBlock,
+                        editCursor.MoveMode.KeepAnchor,
                     )
                     text1 = editCursor.selectedText()
                     text2 = text1.rstrip()
@@ -627,7 +629,9 @@ class PyzoEditor(BaseTextCtrl):
             if not endsAtNextBlock:
                 # Could not move to the beginning of the next block because the end of the
                 # document was reached. Therefore move till the end of the document.
-                cursor.movePosition(cursor.MoveOperation.End, cursor.MoveMode.KeepAnchor)
+                cursor.movePosition(
+                    cursor.MoveOperation.End, cursor.MoveMode.KeepAnchor
+                )
         else:
             # There is selected text and the cursor is at the beginning of the block.
             endsAtNextBlock = True
@@ -830,7 +834,7 @@ if __name__ == "__main__":
             pass
 
     pyzo.parser = DummyParser()
-    EditorContextMenu = QtWidgets.QMenu  # noqa
+    EditorContextMenu = QtWidgets.QMenu
     app = QtWidgets.QApplication([])
     win = PyzoEditor(None)
     QtWidgets.QShortcut(QtGui.QKeySequence("Ctrl+C"), win).activated.connect(win.copy)
